@@ -11,12 +11,12 @@
 #ifndef _INTEGER_INPUT_DIALOG_H
 #define _INTEGER_INPUT_DIALOG_H
 
-#include <kdialog.h>
+#include <qdialog.h>
 
-class KIntSpinBox;
+class QSpinBox;
 class QSlider;
 
-class IntegerInputDialog : public KDialog
+class IntegerInputDialog : public QDialog
 {
 Q_OBJECT
 	public:
@@ -35,7 +35,7 @@ Q_OBJECT
 		void spinboxValueChanged(int newValue);
 
 	private:
-		KIntSpinBox *_spinBox;
+		QSpinBox *_spinBox;
 		QSlider  *_slider;
 };
 
