@@ -10,24 +10,21 @@
 
 #include "kgeography.h"
 
-#include <kaction.h>
-#include <kdialog.h>
-#include <klocale.h>
 #include <kconfigdialog.h>
-#include <kinputdialog.h>
 #include <kmessagebox.h>
-#include <kpushbutton.h>
 #include <kstandardaction.h>
 #include <ktoggleaction.h>
 #include <ktoolbar.h>
-#include <kmenubar.h>
-#include <kicon.h>
 #include <kactioncollection.h>
+#include <klocalizedstring.h>
+
+#include <qmenubar.h>
 #include <qfile.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qsize.h>
 #include <qtimer.h>
+#include <qpushbutton.h>
 
 #include "answersdialog.h"
 #include "capitaldivisionasker.h"
@@ -55,32 +52,29 @@ kgeography::kgeography() : KXmlGuiWindow(), p_firstShow(true), p_mustShowResults
 
 	QWidget *leftWidget = new QWidget(p_bigWidget);
 	QVBoxLayout *leftWidgetLayout = new QVBoxLayout(leftWidget);
-// 	leftWidgetLayout -> setSpacing(0);
-// 	leftWidgetLayout -> setMargin(0);
 
 	p_currentMap = new QLabel(leftWidget);
 	p_currentMap -> setAlignment(Qt::AlignCenter);
-	p_consult = new KPushButton(i18n("E&xplore Map"), leftWidget);
+	p_consult = new QPushButton(i18n("E&xplore Map"), leftWidget);
 	p_consult->setWhatsThis(i18n("In this section left click on any part of the map to learn about the divisions" ));
 	QLabel * testYourselfLabel = new QLabel( i18n("Test Yourself:"), this );
 	testYourselfLabel->setAlignment( Qt::AlignHCenter );
-	p_askMap = new KPushButton(i18n("&Location of Regions"), leftWidget);
+	p_askMap = new QPushButton(i18n("&Location of Regions"), leftWidget);
 	p_askMap->setWhatsThis(i18n("In this challenge you are given a division name on the left under the menu and you must find it on the map and click on it"));
-	p_askPlaceMap = new KPushButton(i18n("&Place Regions in the Map"), leftWidget);
+	p_askPlaceMap = new QPushButton(i18n("&Place Regions in the Map"), leftWidget);
 	p_askPlaceMap->setWhatsThis(i18n("In this challenge you are given the shape of a region and you must place it on the map"));
-	p_askCapitalDivisions = new KPushButton(i18n("&Regions by Capital"), leftWidget);
+	p_askCapitalDivisions = new QPushButton(i18n("&Regions by Capital"), leftWidget);
 	p_askCapitalDivisions->setWhatsThis(i18n("In this quiz you have to guess the division name given its capital"));
-	p_askDivisionCapitals = new KPushButton(i18n("&Capitals of Regions"), leftWidget);
+	p_askDivisionCapitals = new QPushButton(i18n("&Capitals of Regions"), leftWidget);
 	p_askDivisionCapitals->setWhatsThis(i18n("In this quiz you have to guess the capital of a given division name"));
-	p_askFlagDivisions = new KPushButton(i18n("Re&gions by Flag"), leftWidget);
+	p_askFlagDivisions = new QPushButton(i18n("Re&gions by Flag"), leftWidget);
 	p_askFlagDivisions->setWhatsThis(i18n("In this quiz you have to guess the division name given its flag"));
-	p_askDivisionFlags = new KPushButton(i18n("&Flags of Regions"), leftWidget);
+	p_askDivisionFlags = new QPushButton(i18n("&Flags of Regions"), leftWidget);
 	p_askDivisionFlags->setWhatsThis(i18n("In this quiz you have to guess the flag of a division given its name"));
 	p_underLeftWidget = new QWidget(leftWidget);
 	// where the number of answers will be shown
-	QVBoxLayout *underLeftWidgetLayout = new QVBoxLayout(p_underLeftWidget);
-	underLeftWidgetLayout -> setSpacing(KDialog::spacingHint());
-	underLeftWidgetLayout -> setMargin(KDialog::marginHint());
+	m_underLeftWidgetLayout = new QVBoxLayout(p_underLeftWidget);
+	m_underLeftWidgetLayout->setMargin(0);
 
 	leftWidgetLayout -> addWidget(p_currentMap);
 	leftWidgetLayout -> addWidget(p_consult);
@@ -103,47 +97,47 @@ kgeography::kgeography() : KXmlGuiWindow(), p_firstShow(true), p_mustShowResults
 	bigWidgetLayout -> addWidget(leftWidget);
 	setCentralWidget(p_bigWidget);
 
-	connect(p_consult, SIGNAL(clicked()), this, SLOT(consult()));
-	connect(p_askMap, SIGNAL(clicked()), this, SLOT(askMap()));
-	connect(p_askPlaceMap, SIGNAL(clicked()), this, SLOT(askPlaceMap()));
-	connect(p_askCapitalDivisions, SIGNAL(clicked()), this, SLOT(askCapitalDivisions()));
-	connect(p_askDivisionCapitals, SIGNAL(clicked()), this, SLOT(askDivisionCapitals()));
-	connect(p_askFlagDivisions, SIGNAL(clicked()), this, SLOT(askFlagDivisions()));
-	connect(p_askDivisionFlags, SIGNAL(clicked()), this, SLOT(askDivisionFlags()));
+	connect(p_consult, &QPushButton::clicked, this, &kgeography::consult);
+	connect(p_askMap, &QPushButton::clicked, this, &kgeography::askMap);
+	connect(p_askPlaceMap, &QPushButton::clicked, this, &kgeography::askPlaceMap);
+	connect(p_askCapitalDivisions, &QPushButton::clicked, this, &kgeography::askCapitalDivisions);
+	connect(p_askDivisionCapitals, &QPushButton::clicked, this, &kgeography::askDivisionCapitals);
+	connect(p_askFlagDivisions, &QPushButton::clicked, this, &kgeography::askFlagDivisions);
+	connect(p_askDivisionFlags, &QPushButton::clicked, this, &kgeography::askDivisionFlags);
 
 	QAction *a = KStandardAction::open(this, SLOT(openMap()), actionCollection());
 	a -> setText(i18n("&Open Map..."));
 
 	a = KStandardAction::quit(this, SLOT(close()), actionCollection());
 	
-	p_zoom =  actionCollection()->add<KToggleAction>( "zoom_select" );
+	p_zoom =  actionCollection()->add<KToggleAction>( QStringLiteral("zoom_select") );
 	p_zoom -> setText(i18n("&Zoom") );
-	p_zoom -> setIcon( KIcon("zoom-in") );
+	p_zoom -> setIcon( QIcon::fromTheme(QStringLiteral("zoom-in")) );
 	p_zoom -> setEnabled(false);
 
-	p_zoomOriginal = actionCollection()->addAction( "zoom_original" );
+	p_zoomOriginal = actionCollection()->addAction( QStringLiteral("zoom_original") );
 	p_zoomOriginal -> setText( i18n("&Original Size") );
-	p_zoomOriginal -> setIcon( KIcon("zoom-original") );
+	p_zoomOriginal -> setIcon( QIcon::fromTheme(QStringLiteral("zoom-original")) );
 	p_zoomOriginal -> setEnabled(false);
 
-	p_zoomAutomatic = actionCollection()->add<KToggleAction>( "zoom_automatic" );
+	p_zoomAutomatic = actionCollection()->add<KToggleAction>( QStringLiteral("zoom_automatic") );
 	p_zoomAutomatic -> setText(  i18n("&Automatic Zoom") );
-	p_zoomAutomatic -> setIcon( KIcon("zoom-fit-best") );
+	p_zoomAutomatic -> setIcon( QIcon::fromTheme(QStringLiteral("zoom-fit-best")) );
 	p_zoomAutomatic -> setEnabled(false);
 
-	p_move = actionCollection()->add<KToggleAction>( "move" );
+	p_move = actionCollection()->add<KToggleAction>( QStringLiteral("move") );
 	p_move->setText( i18n("&Move") );
-	p_move->setIcon( KIcon("transform-move") );
+	p_move->setIcon( QIcon::fromTheme(QStringLiteral("transform-move")) );
 	p_move -> setEnabled(false);
 
-	a = actionCollection()->addAction( "disclaimer" );
+	a = actionCollection()->addAction( QStringLiteral("disclaimer") );
 	a->setText( i18n("Disclaimer") );
-	connect(a, SIGNAL(triggered()), this, SLOT(disclaimer()));
+	connect(a, &QAction::triggered, this, &kgeography::disclaimer);
 	
-	p_showAuthor = actionCollection()->addAction( "author" );
+	p_showAuthor = actionCollection()->addAction( QStringLiteral("author") );
 	p_showAuthor->setText( i18n("Map author") );
 	p_showAuthor->setEnabled(false);
-	connect(p_showAuthor, SIGNAL(triggered()), this, SLOT(showMapAuthor()));
+	connect(p_showAuthor, &QAction::triggered, this, &kgeography::showMapAuthor);
 
 	KStandardAction::preferences(this, SLOT(showPreferencesDialog()), actionCollection());
 
@@ -160,24 +154,24 @@ kgeography::~kgeography()
 
 void kgeography::showPreferencesDialog()
 {
-	if ( KConfigDialog::showDialog( "settings" ) )
+	if ( KConfigDialog::showDialog( QStringLiteral("settings") ) )
 		return; 
 
 	// KConfigDialog didn't find an instance of this dialog, so lets
 	// create it : 
-	KConfigDialog* dialog = new KConfigDialog(this, "settings",
+	KConfigDialog* dialog = new KConfigDialog(this, QStringLiteral("settings"),
 											  kgeographySettings::self()); 
-        dialog->setHelp("configuration", "kgeography");
+//	FIXME: Waiting for the answer from Kévin about what to do with it
+//	dialog->setHelp("configuration", "kgeography");
 	QWidget *w = new QWidget();
 	Ui::Options confWdg;
 	confWdg.setupUi(w);
 
-	dialog->addPage(w, i18n("General"), "kgeography" ); 
+	dialog->addPage(w, i18n("General"), QStringLiteral("kgeography") ); 
 
 	// User edited the configuration - update your local copies of the 
 	// configuration data 
-	connect(dialog, SIGNAL(settingsChanged(const QString&)), 
-			this, SLOT(updateConfiguration()) ); 
+	connect(dialog, &KConfigDialog::settingsChanged, this, &kgeography::updateConfiguration);
 
 	dialog->show();
 }
@@ -225,7 +219,7 @@ void kgeography::showEvent(QShowEvent *)
 		}
 		// if anyone can explain why with the slot works and now without
 		// i'll be glad to learn
-		QTimer::singleShot(0, this, SLOT(resizeMainWindow()));
+		QTimer::singleShot(0, this, &kgeography::resizeMainWindow);
 // 		resizeMainWindow();
 
 		p_firstShow = false;
@@ -241,7 +235,7 @@ void kgeography::openMap()
 		setMap(mp.getMap());
 		// if anyone can explain why with the slot works and now without
 		// i'll be glad to learn
-		QTimer::singleShot(0, this, SLOT(resizeMainWindow()));
+		QTimer::singleShot(0, this, &kgeography::resizeMainWindow);
 // 		resizeMainWindow();
 	}
 }
@@ -401,14 +395,15 @@ void kgeography::putAskWidget()
 	static_cast<QBoxLayout*>(p_bigWidget -> layout()) -> addWidget(p_askWidget, 1);
 	p_askWidget -> setAutomaticZoom(p_zoomAutomatic -> isChecked());
 	p_askWidget -> show();
-	connect(p_askWidget, SIGNAL(setZoomActionChecked(bool)), p_zoom, SLOT(setChecked(bool)));
-	connect(p_zoom, SIGNAL(toggled(bool)), p_askWidget, SLOT(setZoom(bool)));
-	connect(p_zoomOriginal, SIGNAL(triggered()), p_askWidget, SLOT(setOriginalZoom()));
-	connect(p_zoomAutomatic, SIGNAL(toggled(bool)), this, SLOT(setAutomaticZoom(bool)));
-	connect(p_askWidget, SIGNAL(setMoveActionEnabled(bool)), this, SLOT(setMoveActionEnabled(bool)));
-	connect(p_askWidget, SIGNAL(setMoveActionChecked(bool)), p_move, SLOT(setChecked(bool)));
-	connect(p_move, SIGNAL(toggled(bool)), p_askWidget, SLOT(setMovement(bool)));
-	connect(p_askWidget, SIGNAL(questionsEnded()), this, SLOT(questionsEnded()));
+	connect(p_askWidget, &askWidget::setZoomActionChecked, p_zoom, &KToggleAction::setChecked);
+	connect(p_zoom, &KToggleAction::toggled, p_askWidget, &askWidget::setZoom);
+	connect(p_zoomOriginal, &QAction::triggered, p_askWidget, &askWidget::setOriginalZoom);
+	connect(p_zoomOriginal, &QAction::triggered, p_zoomAutomatic, &QAction::setChecked);
+	connect(p_zoomAutomatic, &KToggleAction::toggled, this, &kgeography::setAutomaticZoom);
+	connect(p_askWidget, &askWidget::setMoveActionEnabled, this, &kgeography::setMoveActionEnabled);
+	connect(p_askWidget, &askWidget::setMoveActionChecked, p_move, &KToggleAction::setChecked);
+	connect(p_move, &KToggleAction::toggled, p_askWidget, &askWidget::setMovement);
+	connect(p_askWidget, &askWidget::questionsEnded, this, &kgeography::questionsEnded);
 }
 
 void kgeography::setMap(KGmap *m)
@@ -416,7 +411,7 @@ void kgeography::setMap(KGmap *m)
 	removeOldAskWidget();
 	kgeographySettings *set = kgeographySettings::self();
 	set -> setLastMap(m -> getFile());
-	set -> writeConfig();
+	set -> save();
 	delete p_map;
 	p_map = m;
 	p_showAuthor->setEnabled(m);
@@ -444,7 +439,12 @@ void kgeography::setMap(KGmap *m)
 
 	// set a maximum width for the under left widget, enabling the labels wordwrap and
 	// avoiding the move of the map in case of large division names.
-	p_underLeftWidget->setMaximumWidth(static_cast<QWidget*>(p_underLeftWidget->parent())->width()- (KDialog::marginHint()+KDialog::spacingHint())*2 );
+	int width = qMax(p_askMap->sizeHint().width(), p_askPlaceMap->sizeHint().width());
+	width = qMax(width, p_askCapitalDivisions->sizeHint().width());
+	width = qMax(width, p_askDivisionCapitals->sizeHint().width());
+	width = qMax(width, p_askFlagDivisions->sizeHint().width());
+	width = qMax(width, p_askDivisionFlags->sizeHint().width());
+	p_underLeftWidget->setMaximumWidth(width);
 }
 
 void kgeography::disclaimer()
@@ -505,4 +505,4 @@ void kgeography::showResultsDialog()
 	}
 }
 
-#include "kgeography.moc"
+
